# clir
[![PyPI](https://img.shields.io/pypi/v/clir)](https://github.com/elkinaguas/clir/releases) ![PyPI - Downloads](https://img.shields.io/pypi/dm/clir) ![Total Download](https://static.pepy.tech/badge/clir)

Clir provides a clear and fast way to store and recover your commands.

## Installation
Install `clir` using pip.

```bash
pip3 install clir
```

## Usage
First of all, initialize clir. This will create the necessary cofig files.
```bash
clir init
```

See all the obption available with
```bash
clir --help
```
![clir --help](https://raw.githubusercontent.com/elkinaguas/clir/main/docs/img/clir_help.png)

List your saved commands:
```bash
clir ls
```
![clir ls](https://raw.githubusercontent.com/elkinaguas/clir/main/docs/img/clir_ls.png)